@@ -11,13 +11,13 @@
 from net_contextdiff import __version__
 
 import argparse
-import re
 import sys
 
 from deepops import deepmerge, deepget
 import yaml
 
 from net_contextdiff.ios import CiscoIOSConfig, CiscoIOSDiffConfig
+from net_contextdiff.misc import deepselect
 
 
 
@@ -222,7 +222,9 @@ parser.add_argument(
     nargs="*",
     default=[],
     help="limit dump options to subtree of configuration dictionary "
-         "with a path specified as list of keys")
+         "with a path specified as list of keys; '-' can be used to "
+         "represent None and values that are parsable as integers will "
+         "be converted to integers")
 
 parser.add_argument(
     "-P", "--debug-parser",
@@ -317,6 +319,37 @@ if not rule_specs:
     ]
 
 
+# if a subtree was specified for debugging 'dump' options, handle some
+# special cases of the elements in the path:
+#
+# * a single dash ('-') is treated as None
+#
+# * if the element can be converted to an integer, do that, rather than
+#   treat it as a string
+#
+# these are to cope with limitations on the parsing available in the
+# ArgumentParser class compared with the flexibility and ambiguity of
+# the configuration dictionary
+
+if subtree_dump_filter:
+    def try_int_else_str(s):
+        "Convert a single path element from a string into another type."
+
+        if s == "-":
+            return None
+
+        try:
+            return int(s)
+        except ValueError:
+            pass
+
+        return s
+
+    subtree_dump_filter = [ try_int_else_str(s) for s in subtree_dump_filter]
+
+    print(subtree_dump_filter)
+
+
 # check a couple of nonsensical configurations aren't being use related
 # to multiple devices
 
@@ -392,7 +425,7 @@ if rules_tree_filename:
 
 if dump_rules >= 1:
     print(">> rule tree:")
-    print(yaml.dump(deepget(diff.get_rules_tree(), *subtree_dump_filter),
+    print(yaml.dump(deepselect(diff.get_rules_tree(), *subtree_dump_filter),
                     default_flow_style=False))
     print(">> rule specs:")
     for spec in rule_specs:
