@@ -26,6 +26,8 @@ from deepops import (
 
 import yaml
 
+from .misc import deepselect
+
 
 
 # --- constants ---
@@ -122,9 +124,8 @@ class DiffConvert:
     block -- the block of configuration in which this converter is to be
     applied (see DiffConfig)
 
-    insert_before -- if this rule needs to happen prior to the actions
-    of another rule, this 2-tuple gives the (path, name) before the
-    earlier rule; None means the order does not matter
+    trigger_blocks -- a set of block names to be triggered when an match
+    is made against this converter
 
     In addition the remove() and update() methods will likely need to be
     implemented.
@@ -988,8 +989,8 @@ class DiffConfig:
 
         if self._dump_config:
             print(">> old configuration (after rules, if specified):",
-                  yaml.dump(deepget(dict(old_cfg),
-                                    *self._subtree_dump_filter),
+                  yaml.dump(deepselect(dict(old_cfg),
+                                       *self._subtree_dump_filter),
                             default_flow_style=False),
                   sep="\n")
 
@@ -1022,8 +1023,8 @@ class DiffConfig:
 
         if self._dump_config:
             print(">> new configuration (after rules, if specified):",
-                  yaml.dump(deepget(dict(new_cfg),
-                                    *self._subtree_dump_filter),
+                  yaml.dump(deepselect(dict(new_cfg),
+                                       *self._subtree_dump_filter),
                             default_flow_style=False),
                   sep="\n")
 
@@ -1042,18 +1043,18 @@ class DiffConfig:
 
         if self._dump_diff:
             print("=> differences - remove:",
-                  yaml.dump(deepget(dict(remove_cfg),
-                                    *self._subtree_dump_filter),
+                  yaml.dump(deepselect(dict(remove_cfg),
+                                       *self._subtree_dump_filter),
                             default_flow_style=False),
 
                   "=> differences - remove full:",
-                  yaml.dump(deepget(dict(remove_cfg_full),
-                                    *self._subtree_dump_filter),
+                  yaml.dump(deepselect(dict(remove_cfg_full),
+                                       *self._subtree_dump_filter),
                             default_flow_style=False),
 
                   "=> differences - update (add/change):",
-                  yaml.dump(deepget(dict(update_cfg),
-                                    *self._subtree_dump_filter),
+                  yaml.dump(deepselect(dict(update_cfg),
+                                       *self._subtree_dump_filter),
                             default_flow_style=False),
 
                   sep="\n")
@@ -1280,9 +1281,8 @@ class DiffConfig:
 
                             if self._debug_convert >= DEBUG_CONVERT_STEPS:
                                 debug_msg += [
-                                    "-> trigger set:",
-                                    pathstr(match_context, set()),
-                                    "block:", t]
+                                    "-> trigger set: %s @ %s"
+                                        % (t, pathstr(match_context, set()))]
 
                             active_triggers.setdefault(t, []).append(
                                 match_context)
@@ -1400,9 +1400,8 @@ class DiffConfig:
 
                             if self._debug_convert >= DEBUG_CONVERT_STEPS:
                                 debug_msg += [
-                                    "-> trigger set:",
-                                    pathstr(match_context, set()),
-                                    "block:", t]
+                                    "-> trigger set: %s @ %s"
+                                        % (t, pathstr(match_context, set()))]
 
                             active_triggers.setdefault(t, []).append(
                                 match_context)
@@ -1428,9 +1427,9 @@ class DiffConfig:
 
                     if self._debug_convert >= DEBUG_CONVERT_STEPS:
                         debug_msg += [
-                            "=> trigger match: "
-                                + pathstr(match, cvt.wildcard_indices),
-                            "block:", cvt.block]
+                            "=> trigger match: %s @ %s"
+                                % (cvt.block,
+                                   pathstr(match, cvt.wildcard_indices))]
 
 
                     args = cvt.get_wildcard_args(match)
