@@ -595,11 +595,28 @@ class Cvt_Int_StandbyTrk(DiffConvert_Int):
 
 class Cvt_Int_StandbyVer(DiffConvert_Int):
     cmd = "standby", "version"
+    block = "int-pre"
+
+    def update(self, old, upd, new, int_name):
+        # only set this here if we're switching to version >= 2 (so we
+        # can potentially use any high-numbered groups)
+        if new < 2:
+            return
+        return [*self.enter(int_name), " standby version " + str(new)]
+
+
+class Cvt_Int_NoStandbyVer(DiffConvert_Int):
+    cmd = "standby", "version"
+    block = "int-post"
 
     def remove(self, old, int_name):
         return [*self.enter(int_name), " no standby version"]
 
     def update(self, old, upd, new, int_name):
+        # only set this here if we're switching to version < 2 (so we
+        # need to do it after removing all the high-numbered groups)
+        if new >= 2:
+            return
         return [*self.enter(int_name), " standby version " + str(new)]
 
 
