@@ -58,6 +58,13 @@ class CiscoIOSDiffConfig(DiffConfig):
             # unconfigured (e.g. HSRP version and high HSRP groups)
             "int-post",
 
+            # tracking objects are deleted in the 'None' block,
+            # including if they are changing type; the new object is
+            # then created, then the sub-configuration (which may need
+            # to be triggered after a type change, to be reapplied)
+            "track-create",
+            "track-sub",
+
             # if we're enabling interfaces, we do that after we've done
             # all the other configuration on them
             "int-noshutdown",
